![CI](https://github.com/jackcizon/dsa_collections/actions/workflows/ci.yaml/badge.svg)

# DSA Collections

collections of data structures and algorithms for learning purposes, with 100% test coverage.

## Install

```shell
pip install dsa_collections
```

## Version

**2.3.1**

## Notes

see license in `LICENSE.txt`